@@ -1,7 +1,7 @@
 use std::sync::Arc;
 
-use garage_rpc::membership::System;
 use garage_rpc::ring::*;
+use garage_rpc::system::System;
 use garage_util::data::*;
 
 use crate::replication::*;
